summaryrefslogtreecommitdiff
path: root/gr-digital/lib/clock_tracking_loop.h
diff options
context:
space:
mode:
Diffstat (limited to 'gr-digital/lib/clock_tracking_loop.h')
-rw-r--r--gr-digital/lib/clock_tracking_loop.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/gr-digital/lib/clock_tracking_loop.h b/gr-digital/lib/clock_tracking_loop.h
index bc4aee1e6a..e8f0fe7989 100644
--- a/gr-digital/lib/clock_tracking_loop.h
+++ b/gr-digital/lib/clock_tracking_loop.h
@@ -415,12 +415,12 @@ namespace gr {
* integrator portion of an IIR filter, so T_avg could potentially
* wander very far during periods of noise/nonsense input.
*
- * This function should be called after advance_loop to keep the
+ * This function is called in advance_loop to keep the
* estimated average clock period, T_avg, in the specified range.
* It is set as a separate method in case another way is desired as
* this is fairly heavy-handed.
*/
- void period_limit();
+ virtual void period_limit();
/*******************************************************************
* SET FUNCTIONS
@@ -415,12 +415,12 @@ namespace gr {
* estimated average clock period, T_avg, in the specified range.
- * It is set as a separate method in case another way is desired as
- * this is fairly heavy-handed.
+ * It is set as a separate virtual method in case another way is desired
+ * as this is fairly heavy-handed.
*/